package com.holmos.cache.cache;

import java.util.ArrayList;
import java.util.List;

import com.holmos.cache.cache.listener.CacheListener;
import com.holmos.cache.config.CacheConfigComponent;
import com.holmos.cache.size.layout.sizegetter.ReflectSizeGetter;
import com.holmos.cache.size.layout.sizegetter.SizeGetter;
import com.holmos.cache.size.layout.sizegetter.SizeGetterFactory;
import com.holmos.cache.status.CacheStatus;
import com.holmos.cache.store.impl.AbstractCacheStore;

/**
 * Holmos 框架 Wasten平台的所有缓存的父类，如果要实现新的缓存的时候，那么需要继承这个类,这个类实现了监听器的执行方法，监听器删减方法
 * 
 * @author: 吴银龙(sunshine307087558@gmail.com)
 * @version: 2013-3-11 下午11:46:43 
 */

public abstract class AbstractCache implements Cache,CacheListener{
	
	protected CacheStatus cacheStatus = new CacheStatus();
	
	protected ArrayList<CacheListener> cacheListeners=new ArrayList<CacheListener>();

	public static ReflectSizeGetter sizeGetter;
	
	protected AbstractCacheStore cacheStore;
	
	static{
		ArrayList<SizeGetter> getters=new ArrayList<SizeGetter>();
		getters.add(SizeGetterFactory.ARRAY_SIZE_GETTER);
		getters.add(SizeGetterFactory.OBJECT_SIZE_GETTER);
		sizeGetter = new ReflectSizeGetter(getters);
	}
	
	@Override
	public List<CacheListener> getAllCacheListeners() {
		return cacheListeners;
	}
	
	@Override
	public void registerCacheListener(CacheListener cacheListener) {
		cacheListeners.add(cacheListener);
	}
	
	@Override
	public void removeCacheListener(CacheListener cacheListener) {
		cacheListeners.remove(cacheListener);
	}
		
	@Override
	public void removeAllCacheListeners() {
		cacheListeners.clear();
	}
	
	@Override
	public void beforeStarted() {
		for(CacheListener listener : cacheListeners)
			listener.beforeStarted();
	}
	
	@Override
	public void afterStarted() {
		for(CacheListener listener : cacheListeners)
			listener.afterStarted();
	}
	
	@Override
	public void beforeDestroyed() {
		for(CacheListener listener : cacheListeners)
			listener.beforeDestroyed();
	}
	
	@Override
	public void afterDestroyed() {
		for(CacheListener listener : cacheListeners)
			listener.afterDestroyed();
	}

	public CacheConfigComponent getCofigComponent() {
		return cacheStore.getConfigComponent();
	}

	public void setCofigComponent(CacheConfigComponent configComponent) {
		cacheStore.setConfigComponent(configComponent);
	}

	public CacheStatus getCacheStatus() {
		return cacheStatus;
	}

	@Override
	public String getName() {
		return cacheStore.getConfigComponent().getName();
	}
	
	public void setName(String name) {
		cacheStore.getConfigComponent().setName(name);
	}
}
